==> org.eclipse.jgit.source_4.8.0.201706111038-r.jar: org/eclipse/jgit/lib/SubmoduleConfig.java <==
/*
 * Copyright (C) 2017, David Pursehouse <david.pursehouse@gmail.com>
 * and other copyright owners as documented in the project's IP log.
 *
 * This program and the accompanying materials are made available
 * under the terms of the Eclipse Distribution License v1.0 which
 * accompanies this distribution, is reproduced below, and is
 * available at http://www.eclipse.org/org/documents/edl-v10.php
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or
 * without modification, are permitted provided that the following
 * conditions are met:
 *
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 *
 * - Redistributions in binary form must reproduce the above
 *   copyright notice, this list of conditions and the following
 *   disclaimer in the documentation and/or other materials provided
 *   with the distribution.
 *
 * - Neither the name of the Eclipse Foundation, Inc. nor the
 *   names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior
 *   written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package org.eclipse.jgit.lib;

import java.util.Locale;

import org.eclipse.jgit.util.StringUtils;

/**
 * Submodule section of a Git configuration file.
 *
 * @since 4.7
 */
public class SubmoduleConfig {

	/**
	 * Config values for submodule.[name].fetchRecurseSubmodules.
	 */
	public enum FetchRecurseSubmodulesMode implements Config.ConfigEnum {
		/** Unconditionally recurse into all populated submodules. */
		YES("true"), //$NON-NLS-1$

		/**
		 * Only recurse into a populated submodule when the superproject
		 * retrieves a commit that updates the submodule's reference to a commit
		 * that isn't already in the local submodule clone.
		 */
		ON_DEMAND("on-demand"), //$NON-NLS-1$

		/** Completely disable recursion. */
		NO("false"); //$NON-NLS-1$

		private final String configValue;

		private FetchRecurseSubmodulesMode(String configValue) {
			this.configValue = configValue;
		}

		@Override
		public String toConfigValue() {
			return name().toLowerCase(Locale.ROOT).replace('_', '-');
		}

		@Override
		public boolean matchConfigValue(String s) {
			if (StringUtils.isEmptyOrNull(s)) {
				return false;
			}
			s = s.replace('-', '_');
			return name().equalsIgnoreCase(s)
					|| configValue.equalsIgnoreCase(s);
		}
	}
}

==> org.eclipse.jgit.source_6.4.0.202211300538-r.jar: org/eclipse/jgit/lib/SubmoduleConfig.java <==
/*
 * Copyright (C) 2017, David Pursehouse <david.pursehouse@gmail.com> and others
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Distribution License v. 1.0 which is available at
 * https://www.eclipse.org/org/documents/edl-v10.php.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */

package org.eclipse.jgit.lib;

import org.eclipse.jgit.util.StringUtils;

/**
 * Submodule section of a Git configuration file.
 *
 * @since 4.7
 */
public class SubmoduleConfig {

	/**
	 * Config values for submodule.[name].fetchRecurseSubmodules.
	 */
	public enum FetchRecurseSubmodulesMode implements Config.ConfigEnum {
		/** Unconditionally recurse into all populated submodules. */
		YES("true"), //$NON-NLS-1$

		/**
		 * Only recurse into a populated submodule when the superproject
		 * retrieves a commit that updates the submodule's reference to a commit
		 * that isn't already in the local submodule clone.
		 */
		ON_DEMAND("on-demand"), //$NON-NLS-1$

		/** Completely disable recursion. */
		NO("false"); //$NON-NLS-1$

		private final String configValue;

		private FetchRecurseSubmodulesMode(String configValue) {
			this.configValue = configValue;
		}

		@Override
		public String toConfigValue() {
			return configValue;
		}

		@Override
		public boolean matchConfigValue(String s) {
			if (StringUtils.isEmptyOrNull(s)) {
				return false;
			}
			s = s.replace('-', '_');
			return name().equalsIgnoreCase(s)
					|| configValue.equalsIgnoreCase(s);
		}
	}
}
